@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -91,7 +91,7 @@ public class ContactFolderLoader implements PublicationDataLoaderService {
             final int folderId = Integer.parseInt(publication.getEntityId());
             final ContactInterface contacts = factory.create(folderId, new PublicationSession(publication));
             final int numberOfContacts = contacts.getNumberOfContacts(folderId);
-            final SearchIterator<Contact> contactsInFolder = contacts.getContactsInFolder(folderId, 0, numberOfContacts, Contact.GIVEN_NAME, Order.ASCENDING, Contact.ALL_COLUMNS);
+            final SearchIterator<Contact> contactsInFolder = contacts.getContactsInFolder(folderId, 0, numberOfContacts, Contact.GIVEN_NAME, Order.ASCENDING, null, Contact.ALL_COLUMNS);
             while(contactsInFolder.hasNext()) {
                 Contact next = contactsInFolder.next();
                 if(!next.getMarkAsDistribtuionlist()) {
