@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,6 +53,7 @@ import java.util.Collection;
 import java.util.List;
 import java.util.Map;
 import com.openexchange.groupware.contexts.Context;
+import com.openexchange.publish.Entity;
 import com.openexchange.publish.Publication;
 import com.openexchange.publish.PublicationException;
 import com.openexchange.publish.PublicationStorage;
@@ -135,4 +136,23 @@ public class DummyStorage implements PublicationStorage {
         
     }
 
+	public List<Publication> getPublicationsOfUser(Context ctx, int userId) throws PublicationException {
+		// TODO Auto-generated method stub
+		return null;
+	}
+
+	public List<Publication> getPublicationsOfUser(Context ctx, int userId,
+			String module) throws PublicationException {
+		// TODO Auto-generated method stub
+		return null;
+	}
+
+    /* (non-Javadoc)
+     * @see com.openexchange.publish.PublicationStorage#isPublished(java.util.List, com.openexchange.groupware.contexts.Context)
+     */
+    public Map<Entity, Boolean> isPublished(List<Entity> entities, Context ctx) throws PublicationException {
+        // TODO Auto-generated method stub
+        return null;
+    }
+
 }
