@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,8 +53,8 @@ import org.osgi.framework.BundleActivator;
 import org.osgi.framework.BundleContext;
 import org.osgi.framework.ServiceRegistration;
 import com.openexchange.ajax.customizer.folder.AdditionalFolderField;
-import com.openexchange.publish.PublicationTargetDiscoveryService;
 import com.openexchange.publish.folders.IsPublished;
+import com.openexchange.publish.helpers.AbstractPublicationService;
 
 
 /**
@@ -65,16 +65,11 @@ import com.openexchange.publish.folders.IsPublished;
  */
 public class FolderFieldActivator implements BundleActivator {
 
-    private static PublicationTargetDiscoveryService DISCOVERER;
 
-    public static void setDiscoverer(PublicationTargetDiscoveryService discoverer) {
-        DISCOVERER = discoverer;
-    }
-    
     private ServiceRegistration registerService;
 
     public void start(final BundleContext context) throws Exception {
-        registerService = context.registerService(AdditionalFolderField.class.getName(), new IsPublished(DISCOVERER), null);
+        registerService = context.registerService(AdditionalFolderField.class.getName(), new IsPublished(AbstractPublicationService.getDefaultStorage()), null);
     }
 
     public void stop(final BundleContext context) throws Exception {
