@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -64,15 +64,16 @@ import java.util.Collection;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import com.openexchange.database.DBPoolingException;
+import com.openexchange.database.provider.DBProvider;
+import com.openexchange.database.provider.DBTransactionPolicy;
 import com.openexchange.datatypes.genericonf.storage.GenericConfigStorageException;
 import com.openexchange.datatypes.genericonf.storage.GenericConfigurationStorageService;
 import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.Types;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.impl.IDGenerator;
-import com.openexchange.groupware.tx.DBProvider;
-import com.openexchange.groupware.tx.DBTransactionPolicy;
-import com.openexchange.groupware.tx.TransactionException;
+import com.openexchange.publish.Entity;
 import com.openexchange.publish.Publication;
 import com.openexchange.publish.PublicationException;
 import com.openexchange.publish.PublicationStorage;
@@ -80,8 +81,10 @@ import com.openexchange.publish.PublicationTargetDiscoveryService;
 import com.openexchange.sql.builder.StatementBuilder;
 import com.openexchange.sql.grammar.DELETE;
 import com.openexchange.sql.grammar.EQUALS;
+import com.openexchange.sql.grammar.Expression;
 import com.openexchange.sql.grammar.IN;
 import com.openexchange.sql.grammar.INSERT;
+import com.openexchange.sql.grammar.LIST;
 import com.openexchange.sql.grammar.SELECT;
 import com.openexchange.sql.grammar.UPDATE;
 import com.openexchange.sql.tools.SQLTools;
@@ -140,7 +143,7 @@ public class PublicationSQLStorage implements PublicationStorage {
         StatementBuilder builder = null;
         try {
             readConnection = dbProvider.getReadConnection(ctx);
-            SELECT select = new SELECT("id", "cid", "user_id", "entity", "module", "configuration_id", "target_id").FROM(publications).WHERE(
+            SELECT select = new SELECT("id", "cid", "user_id", "entity", "module", "configuration_id", "target_id", "enabled").FROM(publications).WHERE(
                 new EQUALS("cid", PLACEHOLDER).AND(new EQUALS("id", PLACEHOLDER)));
 
             List<Object> values = new ArrayList<Object>();
@@ -181,13 +184,13 @@ public class PublicationSQLStorage implements PublicationStorage {
         StatementBuilder builder = null;
         try {
             readConnection = dbProvider.getReadConnection(ctx);
-            SELECT select = new SELECT("id", "cid", "user_id", "entity", "module", "configuration_id", "target_id").FROM(publications).WHERE(
+            SELECT select = new SELECT("id", "cid", "user_id", "entity", "module", "configuration_id", "target_id", "enabled").FROM(publications).WHERE(
                 new EQUALS("cid", PLACEHOLDER).AND(new EQUALS("module", PLACEHOLDER)).AND(new EQUALS("entity", PLACEHOLDER)));
-
-            List<Object> values = new ArrayList<Object>();
-            values.add(I(ctx.getContextId()));
+        	
+        	List<Object> values = new ArrayList<Object>();
+        	values.add(I(ctx.getContextId()));
             values.add(module);
-            values.add(entityId);
+            values.add(entityId);          
 
             builder = new StatementBuilder();
             resultSet = builder.executeQuery(readConnection, select, values);
@@ -219,7 +222,7 @@ public class PublicationSQLStorage implements PublicationStorage {
         StatementBuilder builder = null;
         try {
             readConnection = dbProvider.getReadConnection(ctx);
-            SELECT select = new SELECT("id", "cid", "user_id", "entity", "module", "configuration_id", "target_id").FROM(publications).WHERE(
+            SELECT select = new SELECT("id", "cid", "user_id", "entity", "module", "configuration_id", "target_id", "enabled").FROM(publications).WHERE(
                 new EQUALS("cid", PLACEHOLDER).AND(new EQUALS("target_id", PLACEHOLDER)));
 
             List<Object> values = new ArrayList<Object>();
@@ -247,21 +250,38 @@ public class PublicationSQLStorage implements PublicationStorage {
 
         return retval;
     }
+    
+    public List<Publication> getPublicationsOfUser(Context ctx, int userId)  throws PublicationException {
+    	return getPublicationsOfUser(ctx, userId, null);
+    }
 
-    public List<Publication> getPublicationsOfUser(Context ctx, int contextId, int userId)  throws PublicationException {
+    public List<Publication> getPublicationsOfUser(Context ctx, int userId, String module)  throws PublicationException {
         List<Publication> retval = null;
-
+        
+        int contextId = ctx.getContextId();
         Connection readConnection = null;
         ResultSet resultSet = null;
         StatementBuilder builder = null;
         try {
             readConnection = dbProvider.getReadConnection(ctx);
-            SELECT select = new SELECT("id", "cid", "user_id", "entity", "module", "configuration_id", "target_id").FROM(publications).WHERE(
-                new EQUALS("cid", PLACEHOLDER).AND(new EQUALS("user_id", PLACEHOLDER)));
+            
+            SELECT select;
+            List<Object> values = new ArrayList<Object>();;
+            if (module == null) {
+            	select = new SELECT("id", "cid", "user_id", "entity", "module", "configuration_id", "target_id", "enabled").FROM(publications).WHERE(
+                        new EQUALS("cid", PLACEHOLDER).AND(new EQUALS("user_id", PLACEHOLDER)));
 
-            List<Object> values = new ArrayList<Object>();
-            values.add(I(contextId));
-            values.add(I(userId));
+                values.add(I(contextId));
+                values.add(I(userId));
+            } else {
+            	select = new SELECT("id", "cid", "user_id", "entity", "module", "configuration_id", "target_id", "enabled").FROM(publications).WHERE(
+                        new EQUALS("cid", PLACEHOLDER).AND(new EQUALS("user_id", PLACEHOLDER)).AND(new EQUALS("module", PLACEHOLDER)));
+
+                values.add(I(contextId));
+                values.add(I(userId));
+                values.add(module);
+            }
+            
 
             builder = new StatementBuilder();
             resultSet = builder.executeQuery(readConnection, select, values);
@@ -384,7 +404,7 @@ public class PublicationSQLStorage implements PublicationStorage {
             throw e;
         } catch (SQLException e) {
             throw SQLException.create(e);
-        } catch (TransactionException e) {
+        } catch (DBPoolingException e) {
             throw new PublicationException(e);
         } finally {
             tryToClose(context, writeConnection);
@@ -398,7 +418,7 @@ public class PublicationSQLStorage implements PublicationStorage {
             deleteWhereContextID(contextId, ctx, writeConnection);
         } catch (SQLException e) {
             throw SQLException.create(e);
-        } catch (TransactionException e) {
+        } catch (DBPoolingException e) {
             throw new PublicationException(e);
         } catch (GenericConfigStorageException e) {
             throw new PublicationException(e);
@@ -423,7 +443,7 @@ public class PublicationSQLStorage implements PublicationStorage {
     }
 
     private void deleteWhereUserID(int userid, Context context, Connection writeConnection) throws SQLException, GenericConfigStorageException, PublicationException {
-        List<Publication> publicated = getPublicationsOfUser(context, context.getContextId(), userid);
+        List<Publication> publicated = getPublicationsOfUser(context, userid);
         for(Publication pub: publicated){
             delete(pub,writeConnection);
             storageService.delete(writeConnection, context, getConfigurationId(pub));
@@ -460,7 +480,7 @@ public class PublicationSQLStorage implements PublicationStorage {
 
         INSERT insert = new INSERT().INTO(publications).SET("id", PLACEHOLDER).SET("cid", PLACEHOLDER).SET("user_id", PLACEHOLDER).SET(
             "entity",
-            PLACEHOLDER).SET("module", PLACEHOLDER).SET("configuration_id", PLACEHOLDER).SET("target_id", PLACEHOLDER);
+            PLACEHOLDER).SET("module", PLACEHOLDER).SET("configuration_id", PLACEHOLDER).SET("target_id", PLACEHOLDER).SET("enabled", PLACEHOLDER);
 
         List<Object> values = new ArrayList<Object>();
         values.add(I(id));
@@ -470,7 +490,8 @@ public class PublicationSQLStorage implements PublicationStorage {
         values.add(publication.getModule());
         values.add(I(configId));
         values.add(publication.getTarget().getId());
-
+        values.add(publication.isEnabled());
+        
         new StatementBuilder().executeStatement(writeConnection, insert, values);
         return id;
     }
@@ -484,22 +505,27 @@ public class PublicationSQLStorage implements PublicationStorage {
         UPDATE update = new UPDATE(publications);
         List<Object> values = new ArrayList<Object>();
 
-        if (publication.getUserId() > 0) {
+        if (publication.containsUserId()) {
             update.SET("user_id", PLACEHOLDER);
             values.add(I(publication.getUserId()));
         }
-        if (publication.getEntityId() != null) {
+        if (publication.containsEntityId()) {
             update.SET("entity", PLACEHOLDER);
             values.add(publication.getEntityId());
         }
-        if (publication.getModule() != null) {
+        if (publication.containsModule()) {
             update.SET("module", PLACEHOLDER);
             values.add(publication.getModule());
         }
-        if (publication.getTarget() != null) {
+        if (publication.containsTarget()) {
             update.SET("target_id", PLACEHOLDER);
             values.add(publication.getTarget().getId());
         }
+        
+        if (publication.containsEnabled()) {
+            update.SET("enabled", PLACEHOLDER);
+            values.add(publication.isEnabled());
+        }
 
         update.WHERE(new EQUALS("cid", PLACEHOLDER).AND(new EQUALS("id", PLACEHOLDER)));
         values.add(I(publication.getContext().getContextId()));
@@ -520,7 +546,8 @@ public class PublicationSQLStorage implements PublicationStorage {
             publication.setId(resultSet.getInt("id"));
             publication.setModule(resultSet.getString("module"));
             publication.setUserId(resultSet.getInt("user_id"));
-
+            publication.setEnabled(resultSet.getBoolean("enabled"));
+            
             Map<String, Object> content = new HashMap<String, Object>();
             storageService.fill(readConnection, ctx, resultSet.getInt("configuration_id"), content);
 
@@ -612,5 +639,56 @@ public class PublicationSQLStorage implements PublicationStorage {
 
         return retval;
     }
+    
+    public Map<Entity, Boolean> isPublished(List<Entity> entities, Context ctx) throws PublicationException {
+        Map<Entity, Boolean> retval = new HashMap<Entity, Boolean>();
+        for (Entity entity : entities) {
+            retval.put(entity, Boolean.FALSE);
+        }
+
+        Connection readConnection = null;
+        ResultSet resultSet = null;
+        StatementBuilder builder = null;
+        try {
+            readConnection = dbProvider.getReadConnection(ctx);
+            ArrayList<Expression> placeholders = new ArrayList<Expression>(entities.size());
+            for(int i = 0; i < entities.size(); i++) {
+                placeholders.add(PLACEHOLDER);
+            }
+            SELECT select = new SELECT("module, entity").FROM(publications).WHERE(new EQUALS("cid", PLACEHOLDER).AND(new IN("entity", new LIST(placeholders))));
+
+            List<Object> values = new ArrayList<Object>();
+            values.add(I(ctx.getContextId()));
+            for (Entity entity : entities) {
+                values.add(entity.getId());
+            }
+
+            builder = new StatementBuilder();
+            resultSet = builder.executeQuery(readConnection, select, values);
+            while (resultSet.next()) {
+                String entityType = resultSet.getString(1);
+                int entityId = resultSet.getInt(2);
+                Entity found = new Entity(entityType, entityId);
+                if (retval.containsKey(found)) {
+                    retval.put(found, Boolean.TRUE);
+                }
+            }
+        } catch (SQLException e) {
+            throw SQLException.create(e);
+        } catch (AbstractOXException e) {
+            throw new PublicationException(e);
+        } finally {
+            try {
+                if (builder != null) {
+                    builder.closePreparedStatement(null, resultSet);
+                }
+            } catch (SQLException e) {
+                throw SQLException.create(e);
+            } finally {
+                dbProvider.releaseReadConnection(ctx, readConnection);
+            }
+        }
+        return retval;
+    }
 
 }
