@@ -1,16 +1,18 @@
 package com.openexchange.publish.tools;
 
+import static com.openexchange.publish.Asserts.assertDoesNotKnow;
+import static com.openexchange.publish.Asserts.assertGettable;
+import static com.openexchange.publish.Asserts.assertKnows;
+import static com.openexchange.publish.Asserts.assertNotGettable;
+import static com.openexchange.publish.Asserts.assertTargets;
 import java.util.Collection;
 import java.util.List;
+import junit.framework.TestCase;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.publish.PublicationException;
 import com.openexchange.publish.PublicationTarget;
 import com.openexchange.publish.SimPublicationService;
 import com.openexchange.publish.SimPublicationTargetDiscoveryService;
-import com.openexchange.publish.tools.CompositePublicationTargetDiscoveryService;
-import junit.framework.TestCase;
-
-import static com.openexchange.publish.Asserts.*;
 
 /*
  *
@@ -42,7 +44,7 @@ import static com.openexchange.publish.Asserts.*;
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -71,6 +73,7 @@ public class CompositePublicationTargetDiscovererTest extends TestCase {
  
     private CompositePublicationTargetDiscoveryService composite;
 
+    @Override
     public void setUp() throws Exception {
         SimPublicationTargetDiscoveryService discovery1 = new SimPublicationTargetDiscoveryService();
         SimPublicationTargetDiscoveryService discovery2 = new SimPublicationTargetDiscoveryService();
@@ -147,4 +150,4 @@ public class CompositePublicationTargetDiscovererTest extends TestCase {
     }
     
 }
- 
\ No newline at end of file
+ 
