@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,17 +49,17 @@
 
 package com.openexchange.publish.tools;
 
+import static com.openexchange.publish.Asserts.assertDoesNotKnow;
+import static com.openexchange.publish.Asserts.assertGettable;
+import static com.openexchange.publish.Asserts.assertKnows;
+import static com.openexchange.publish.Asserts.assertTargets;
 import java.util.Collection;
-import com.openexchange.groupware.contexts.SimContext;
+import junit.framework.TestCase;
 import com.openexchange.groupware.contexts.Context;
+import com.openexchange.groupware.contexts.SimContext;
 import com.openexchange.publish.PublicationException;
 import com.openexchange.publish.PublicationTarget;
 import com.openexchange.publish.SimPublicationService;
-import com.openexchange.publish.tools.PublicationTargetCollector;
-
-import junit.framework.TestCase;
-
-import static com.openexchange.publish.Asserts.*;
 
 /**
  * {@link PublicationTargetCollectorTest}
@@ -91,6 +91,7 @@ public class PublicationTargetCollectorTest extends TestCase {
         target1.setPublicationService(pubService1);
         
         SimPublicationService pubService2 = new SimPublicationService() {
+            @Override
             public boolean knows(Context ctx, int publicationId) {
                 return publicationId == 12;
             }
